@@ -1,26 +1,35 @@
 library("globals")
 
 b <- 2
-expr <- substitute({ a <- b; b <- 1 }, env=list())
+c <- 3
+d <- NULL
+expr <- substitute({ x <- b; b <- 1; y <- c; z <- d }, env=list())
 
 message("*** findGlobals():")
 globalsC <- findGlobals(expr, method="conservative")
 print(globalsC)
+stopifnot(all(globalsC %in% c("{", "<-", "c", "d")))
+
 globalsL <- findGlobals(expr, method="liberal")
 print(globalsL)
+stopifnot(all(globalsL %in% c("{", "<-", "b", "c", "d")))
+
 
 message("*** globalsOf():")
 globalsC <- globalsOf(expr, method="conservative")
-print(globalsC)
+str(globalsC)
+stopifnot(all(names(globalsC) %in% c("{", "<-", "c", "d")))
 globalsC <- cleanup(globalsC)
-print(globalsC)
-stopifnot(length(globalsC) == 0L)
+str(globalsC)
+stopifnot(all(names(globalsC) %in% c("c", "d")))
+
 globalsL <- globalsOf(expr, method="liberal")
-print(globalsL)
+str(globalsL)
+stopifnot(all(names(globalsL) %in% c("{", "<-", "b", "c", "d")))
 globalsL <- cleanup(globalsL)
-print(globalsL)
-stopifnot(length(globalsL) == 1L)
-stopifnot(names(globalsL) == "b")
+str(globalsL)
+stopifnot(all(names(globalsL) %in% c("b", "c", "d")))
+
 
 message("*** Subsetting of Globals:")
 globalsL <- globalsOf(expr, method="liberal")
@@ -28,23 +37,28 @@ globalsS <- globalsL[-1]
 stopifnot(length(globalsS) == length(globalsL) - 1L)
 stopifnot(identical(class(globalsS), class(globalsL)))
 
+
 message("*** cleanup() & packagesOf():")
 globals <- globalsOf(expr, method="conservative")
-print(globals)
+str(globals)
+stopifnot(all(names(globals) %in% c("{", "<-", "c", "d")))
 
 globals <- as.Globals(globals)
-print(globals)
+str(globals)
+stopifnot(all(names(globals) %in% c("{", "<-", "c", "d")))
 
 globals <- as.Globals(unclass(globals))
-print(globals)
+str(globals)
+stopifnot(all(names(globals) %in% c("{", "<-", "c", "d")))
 
 pkgs <- packagesOf(globals)
 print(pkgs)
+stopifnot(length(pkgs) == 0L)
 
 globals <- cleanup(globals)
-print(globals)
-stopifnot(length(globals) == 0L)
+str(globals)
+stopifnot(all(names(globals) %in% c("c", "d")))
 
 pkgs <- packagesOf(globals)
 print(pkgs)
-
+stopifnot(length(pkgs) == 0L)
